package com.nokia.financeapi.controller.house;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.pojo.dto.GetBuildingAreaStatDto;
import com.nokia.financeapi.pojo.dto.GetBuildingMapDto;
import com.nokia.financeapi.pojo.dto.GetBuildingOptionsDto;
import com.nokia.financeapi.pojo.dto.GetBuildingRepairStatDto;
import com.nokia.financeapi.pojo.dto.GetHouseNoticeDto;
import com.nokia.financeapi.pojo.dto.GetLandBuildingStatDto;
import com.nokia.financeapi.pojo.vo.GetBuildingAreaStatVo;
import com.nokia.financeapi.pojo.vo.GetBuildingMapVo;
import com.nokia.financeapi.pojo.vo.GetBuildingOptionsVo;
import com.nokia.financeapi.pojo.vo.GetBuildingRepairStatVo;
import com.nokia.financeapi.pojo.vo.GetHouseNoticeVo;
import com.nokia.financeapi.pojo.vo.GetLandBuildingStatVo;
import com.nokia.financeapi.pojo.vo.GetRentOutStatVo;
import com.nokia.financeapi.pojo.vo.TreeAreaVo;
import com.nokia.financeapi.service.house.HouseResourceMapService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

@Tag(name = "不动产资源地图")
@RestController
@RequestMapping("/house-car/house/resource-map/api")
public class HouseResourceMapController {
    private final HouseResourceMapService houseResourceMapService;

    public HouseResourceMapController(HouseResourceMapService houseResourceMapService) {
        this.houseResourceMapService = houseResourceMapService;
    }

    @Operation(summary = "获取建筑面积统计")
    @PostMapping("/getBuildingAreaStat")
    public R<GetBuildingAreaStatVo> getBuildingAreaStat(@Valid @RequestBody GetBuildingAreaStatDto dto) {
        return houseResourceMapService.getBuildingAreaStat(dto);
    }

    @Operation(summary = "获取土地和建筑统计")
    @PostMapping("/getLandBuildingStat")
    public R<List<GetLandBuildingStatVo>> getLandBuildingStat(@Valid @RequestBody GetLandBuildingStatDto dto) {
        return houseResourceMapService.getLandBuildingStat(dto);
    }

    @Operation(summary = "查询地区树形")
    @PostMapping("/treeArea")
    public R<TreeAreaVo> treeArea() {
        return houseResourceMapService.treeArea();
    }

    @Operation(summary = "获取资源地图建筑列表")
    @PostMapping("/getBuildingMap")
    public R<List<GetBuildingMapVo>> getBuildingMap(@Valid @RequestBody GetBuildingMapDto dto) {
        return houseResourceMapService.getBuildingMap(dto);
    }

    @Operation(summary = "获取房屋维修统计")
    @PostMapping("/getBuildingRepairStat")
    public R<List<GetBuildingRepairStatVo>> getBuildingRepairStat(@Valid @RequestBody GetBuildingRepairStatDto dto) {
        return houseResourceMapService.getBuildingRepairStat(dto);
    }

    @Operation(summary = "获取公告列表")
    @PostMapping("/getNotice")
    public R<List<GetHouseNoticeVo>> getNotice(@Valid @RequestBody GetHouseNoticeDto dto) {
        return houseResourceMapService.getNotice(dto);
    }

    @Operation(summary = "获取出租收入统计")
    @PostMapping("/getRentOutStat")
    public R<List<GetRentOutStatVo>> getRentOutStat() {
        return houseResourceMapService.getRentOutStat();
    }

    @Operation(summary = "获取建筑选项列表")
    @PostMapping("/getBuildingOptions")
    public R<List<GetBuildingOptionsVo>> getBuildingOptions(@Valid @RequestBody GetBuildingOptionsDto dto) {
        return houseResourceMapService.getBuildingOptions(dto);
    }
}
