package com.nokia.financeapi.service.car;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.dao.car.CarResourceMapMapper;
import com.nokia.financeapi.pojo.dto.GetCarCostStatDto;
import com.nokia.financeapi.pojo.dto.GetCarMapStatDto;
import com.nokia.financeapi.pojo.dto.GetCarNoticeDto;
import com.nokia.financeapi.pojo.dto.GetCarTypeStatDto;
import com.nokia.financeapi.pojo.dto.GetDriveStatDto;
import com.nokia.financeapi.pojo.vo.GetCarCostStatVo;
import com.nokia.financeapi.pojo.vo.GetCarMapStatVo;
import com.nokia.financeapi.pojo.vo.GetCarNoticeVo;
import com.nokia.financeapi.pojo.vo.GetCarTypeStatVo;
import com.nokia.financeapi.pojo.vo.GetDriveStatVo;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
public class CarResourceMapService {
    private final CarResourceMapMapper carResourceMapMapper;

    public CarResourceMapService(CarResourceMapMapper carResourceMapMapper) {
        this.carResourceMapMapper = carResourceMapMapper;
    }

    public R<List<GetCarNoticeVo>> getNotice(GetCarNoticeDto dto) {
        if (!StringUtils.hasText(dto.getCity())) {
            dto.setCity("全省");
        }
        List<GetCarNoticeVo> vo = carResourceMapMapper.getNotice(dto);
        return R.ok(vo);
    }

    public R<GetCarTypeStatVo> getCarTypeStat(GetCarTypeStatDto dto) {
        GetCarTypeStatVo vo = carResourceMapMapper.getCarTypeStat(dto);
        return R.ok(vo);
    }

    public R<List<GetCarMapStatVo>> getCarMapStat(GetCarMapStatDto dto) {
        if (StringUtils.hasText(dto.getCity())) {
            List<GetCarMapStatVo> vo = carResourceMapMapper.getDistrictCarMapStat(dto);
            return R.ok(vo);
        }
        List<GetCarMapStatVo> vo = carResourceMapMapper.getCityCarMapStat();
        return R.ok(vo);
    }

    public R<List<GetDriveStatVo>> getDriveStat(GetDriveStatDto dto) {
        if (StringUtils.hasText(dto.getCity())) {
            List<GetDriveStatVo> vo = carResourceMapMapper.getDistrictDriveStat(dto);
            return R.ok(vo);
        }
        List<GetDriveStatVo> vo = carResourceMapMapper.getCityDriveStat();
        return R.ok(vo);
    }

    public R<List<GetCarCostStatVo>> getCarCostStat(GetCarCostStatDto dto) {
        if (StringUtils.hasText(dto.getCity())) {
            List<GetCarCostStatVo> vo = carResourceMapMapper.getDistrictCostStat(dto);
            return R.ok(vo);
        }
        List<GetCarCostStatVo> vo = carResourceMapMapper.getCityCostStat();
        return R.ok(vo);
    }
}
